@@ -335,9 +335,11 @@ void BookWindow::ShowSection(int section)
                                                     .arg(m_Font.pixelSize());
             html.append(customStyle);
         }
-        html.append("</head>");
+        html.append("</head><body>");
+        if (section > 0)
+            html.append(QString("<h3 style=\"text-align:center;\">- %1 -</h3>").arg(section));
         html.append(m_Section->Text);
-        html.append("</html>");
+        html.append("</body></html>");
 
         ui->webView->setFixedHeight(30);
         ui->webView->setHtml(html, baseUrl);
