@@ -102,6 +102,8 @@ int Weapon::GetClass(QString wclass)
         return Weapon::Quarterstaff;
     else if (!QString::compare(wclass, "Broadsword", Qt::CaseInsensitive))
         return Weapon::Broadsword;
+    else if (!QString::compare(wclass, "Bow", Qt::CaseInsensitive))
+        return Weapon::Bow;
     return Weapon::None;
 }
 
@@ -153,6 +155,9 @@ QString Weapon::ClassDescription(int Class)
     case Broadsword:
         return "Broadsword";
         break;
+    case Bow:
+        return "Bow";
+        break;
     default:
         return "";
         break;
