@@ -16,6 +16,7 @@ public:
     int BaseEndurance;
     int Endurance;
 
+    int Arrows;
     int GoldCrowns;
     int TemporaryCombatSkillDelta;
 
@@ -33,7 +34,6 @@ public:
     QList<Item*> HiddenItems;
 
     int DeathsCount;
-    int MealsCount();
 
     static QString GetRankDescription(int kaiDisciplinesCount);
     QHash<QString, QString> Properties;
@@ -89,12 +89,17 @@ public slots:
     Item* AddMeal(QString name);
     Item* AddHealingItem(QString name, int enduranceRestore);
 
+    int GetArrows() { return Arrows; }
+    void SetArrows(int value) { Arrows = value; }
+
     int GetGoldCrowns();
     void SetGoldCrowns(int);
 
     int SpecialItemsCount();
     // Return the number of backpack items
     int ItemsCount();
+    // Return the number of meals
+    int MealsCount();
     QStringList GetSpecialItems();
     QStringList GetItems();
 
